Learn R Programming

gcmr (version 0.3)

cluster.cormat: Gaussian Copula Regression with Longitudinal/Clustered Data Correlation Matrix

Description

Sets longitudinal/clustered data correlation in Gaussian copula regression models.

Usage

cluster.cormat(id, type = c("ar1", "ma1", "exch", "unstr"))

Arguments

id
subject id. This is a vector of the same lenght of the number of observations. Please note that data must be sorted in way that observations from the same cluster are contiguous.
type
a character string specifying the correlation structure. At the moment, the following are implemented: ll{ ar1 autoregressive of order 1. ma1 moving average of order 1. exch exchangeable.

Value

  • An object of class cormat.gcmr representing a correlation matrix for longitudinal or clustered data.

Details

The correlation matrices are inherited from the nlme package (Pinheiro and Bates, 2000).

References

Masarotto, G. and Varin, C. (2011). Gaussian copula regression models. Preprint.

Pinheiro, J.C. and Bates, D.M. (2000). Mixed-Effects Models in S and S-PLUS. Springer.

See Also

gcmr, nlme