Learn R Programming

gcmr (version 0.7.5)

epilepsy: Epilitic Seizures Data

Description

Longitudinal study on epilitic seizures (Thall and Vail, 1990; Diggle et al. 2002). The data consist into 59 individuals with five observations each: The baseline eight-week interval and measurements collected at subsequent visits every two-week.

Usage

data(epilepsy)

Arguments

Format

id
patient's id .
age
patient's age.
trt
indicator if the patient is treated with progabide (1) or with placebo (2).
counts
number of epileptic seizures.
time
observation period in weeks (8 for baseline and 2 for subsequent visits).
visit
indicator if observation at baseline (0) or subsequent visit (1).

Thall, P.F. and Vail S.C. (1990). Some covariance models for longitudinal count data with overdispersion. Biometrics 46, 657--671.

References

Diggle, P.J., Heagerty, P., Liang, K.Y. and Zeger, S.L. (2002). Analysis of Longitudinal Data. Oxford: Oxford University Press. Second edition.