Learn R Programming

gcmr (version 0.3)

estfun.gcmr: Bread and Salami for Sandwich Estimation in Gaussian Marginal Regression Models

Description

Extracts empirical estimating functions (aka salami) and the inverse of (minus) the Hessian (aka bread) of a fitted Gaussian marginal regression model for computation of the sandwich variance-covariance matrix (Zeleis, 2006).

Usage

## S3 method for class 'gcmr':
estfun(x, ...)
## S3 method for class 'gcmr':
bread(x, ...)

Arguments

x
a fitted marginal regression model of class gcmr.
...
further arguments passed to methods.

Value

  • estfun: a matrix containing the empirical estimating functions.

    bread: a matrix containing the inverse of (minus) the Hessian.

Details

These functions are passed to sandwich (Zeleis, 2006).

References

Zeleis, A. (2006). Object-oriented computation of sandwich estimators. Journal of Statistical Software 16, issue 9.

See Also

bread, estfun, gcmr, sandwich