At the moment, the following are implemented:beta.marg beta marginals.
binomial.marg binomial marginals.
Gamma.marg Gamma marginals.
gaussian.marg Gaussian marginals.
negbin.marg negative binomial marginals.
poisson.marg Poisson marginals.
weibull.marg Weibull marginals.
}
beta.marg(link = "logit")
binomial.marg(link = "logit")
Gamma.marg(link = "inverse")
gaussian.marg(link = "identity")
negbin.marg(link = "log")
poisson.marg(link = "log")
weibull.marg(link = "log")family for the special case of generalized linear models.marginal.gcmr representing the marginal component.beta.marg are parametrized in terms of mean and dispersion as in betareg. See Cribari-Neto and Zeileis (2010) and Ferrari and Cribari-Neto (2004). For binomial marginals specified by binomial.marg the response is specified as a factor when the first level denotes failure and all others success or as a two-column matrix with the columns giving the numbers of successes and failures.
Negative binomial marginals implemented in negbin.marg are parametrized such that $var(Y)=E(Y)+k E(Y)^2$.
For back-compatibility with previous versions of the gcmr package, short names for the marginals bn.marg, gs.marg, nb.marg, and ps.marg remain valid as an alternative to (preferred) longer versions binomial.marg, gaussian.marg, negbin.marg, and poisson.marg.
Ferrari, S.L.P. and Cribari-Neto, F. (2004). Beta regression for modeling rates and proportions. Journal of Applied Statistics 31 (7), 799--815.
Masarotto, G. and Varin, C. (2012). Gaussian copula marginal regression. Electronic Journal of Statistics 6, 1517--1549.
gcmr, betareg.