This package contains R functions that implement the methodology discussed in Masarotto and Varin (2012) and Guolo and Varin (2014). The main function is gcmr, which fits Gaussian copula marginal regression models. Inference is performed through a likelihood approach. Computation of the exact likelihood is possible only for continuous responses, otherwise the likelihood function is approximated by importance sampling. See Masarotto and Varin (2012) for details.
Masarotto, G. and Varin, C. (2012). Gaussian copula marginal regression. Electronic Journal of Statistics 6, 1517--1549. http://projecteuclid.org/euclid.ejs/1346421603.
Nikoloulopoulos A (2015). Efficient Estimation of High-dimensional Multivariate Normal Copula Models with Discrete Spatial Responses. Stochastic Environmental Research and Risk Assessment, to appear.
Song, P. X.-K. (2000). Multivariate dispersion models generated from Gaussian copula. Scandinavian Journal of Statistics 27, 305--320.
Song, P. X.-K., Li, M. and Zhang, P. (2013). Copulae in Mathematical and Quantitative Finance. In Vector Generalized Linear Models: A Gaussian Copula Approach, 251--276. Springer Berlin Heidelberg.