gcmr.options(seed = round(runif(1, 1, 1e+05)), nrep = c(100, 1000), no.se = FALSE, method = c("BFGS", "Nelder-Mead", "CG"), ...)nrep can be a vector so that the model is fitted with a sequence of different Monte Carlo sizes. In this case, the starting values for optimization of the likelihood are taken from the previous fitting. A reasonable strategy is to fit the model with a small Monte Carlo size to obtain sensible starting values and then refit with a larger Monte Carlo size. The default value is 100 for the first optimization and 1000 for the second and definitive optimization.
optim. The default optimization routine is the quasi-Newton algorithm BFGS. See optim for details.
optim.
gcmr