Learn R Programming

gcmr (version 0.2)

gs.marg: Sets the Marginals in Gaussian Copula Marginal Regression Models

Description

These functions set the marginals in Gaussian copula marginal regression models.

At the moment, the following are implemented:ll{ gs.marg normal margins. bn.marg binomial margins. ps.marg Poisson margins. nb.marg negative binomial margins. }

Usage

gs.marg(link = "identity")
bn.marg(link = "logit")
ps.marg(link = "log")
nb.marg(link = "log")

Arguments

link
a specification for the model link function. See family for the special case of generalized linear models.

Value

  • An object of class marginal.gcmr representing the marginal component.

Details

For binomial marginals specified by bn.marg the response is specified as a factor when the first level denotes failure and all others success or as a two-column matrix with the columns giving the numbers of successes and failures.

Negative binomial margins implemented in nb.marg are parameterized such that $var(Y)=E(Y)+k E(Y)^2$.

References

Masarotto, G. and Varin, C. (2011). Gaussian copula marginal regression. Preprint.

See Also

gcmr