Learn R Programming

gcmr (version 0.2)

hausman: Hausman-type specification test

Description

Computes the Hausman-type specification test for validation of the multivariate normal assumption in Gaussian copula marginal regression models. The p-value of the test is estimated via parametric Bootstrap.

Usage

hausman(m, method = c("one-step", "full"), 
        nboot = if (method == "one-step") 1000 else 200, 
        nrep = 200)

Arguments

m
a fitted marginal regression model of class gcmr.
method
"one-step" for a first-order approximation of the solution or "full" for a complete optimization for each Bootstrap sample.
nboot
number of Bootstrap replicates.
nrep
sets the value of parameter nrep in function gcmr.options.

Value

  • A list with the following components: ll{ overall the overall Hausman-type specification test. parameters the Hausman-type specification test for each single marginal parameter. options the options used (method, nboot, nrep). }

Details

The option method="full" gives more precise answers but at considerable higher computational cost.

References

Hausman, J.A. (1978). Specification tests in econometrics. Econometrica 46, 1251--1271. Masarotto, G. and Varin, C. (2011). Gaussian copula marginal regression. Preprint.

See Also

gcmr