Learn R Programming

gcmr (version 0.7.5)

malaria: Gambia Malaria Data

Description

Malaria prevalence in children in Gambia. The data are constructed from the gambia dataframe in the geoR package (Diggle and Ribeiro, 2007) by village aggregation.

Usage

data(malaria)

Arguments

Format

A data frame with the 65 observations with the following variables
x
x-coordinate of the village (UTM).
y
y-coordinate of the village (UTM).
cases
number of sampled children with malaria in each village.
size
number of sampled children in each village.
age
mean age of the sampled children in each village.
netuse
frequency of sampled children who regularly sleep under a bed-net in each village.
treated
frequency of sampled children whose bed-net is treated.
green
measure of vegetation green-ness in the immediate vicinity of the village.
phc
indicator variable denoting the presence (1) or absence (0) of a health center in the village.
area
indicator of the village area (Diggle et al., 2002).

Diggle, P.J. and Ribeiro Jr, P.J. (2007). Model Based Geostatistics. New York: Springer.

References

Thomson, M., Connor, S., D Alessandro, U., Rowlingson, B., Diggle, P., Cresswell, M. and Greenwood, B. (1999). Predicting malaria infection in Gambian children from satellite data and bednet use surveys: the importance of spatial correlation in the interpretation of results. American Journal of Tropical Medicine and Hygiene 61, 2--8.

Diggle, P., Moyeed, R., Rowlingson, B. and Thomson, M. (2002). Childhood malaria in The Gambia: a case-study in model-based geostatistics, Applied Statistics 51, 493--506.

Examples

Run this code
data(malaria)

Run the code above in your browser using DataLab