Learn R Programming

gcmr (version 0.7.5)

summary.gcmr: Methods for gcmr Objects

Description

Methods for extracting information from fitted beta regression model objects of class "gcmr".

Usage

"summary"(object, ...)
"coef"(object, ...) "vcov"(object, ...) "bread"(x, ...) "estfun"(x, ...)

Arguments

object, x
a fitted marginal regression model of class gcmr.
...
additional arguments, but currently not used.

Value

The function summary.gcmr returns an object of class "summary.glm", a list with some components of the gcmr object, plus
coefficients
a list with components marginal and copula containing the maximum likelihood estimates of the marginal and Gaussian copula parameters, respectively.
aic
Akaike Information Criterion.
Function coef returns the estimated coefficients and vcov their variance-covariance matrix. Functions bread and estfun extract the components of the robust sandwich variance matrix that can be computed with the sandwich package (Zeileis, 2004; 2006).

References

Zeileis, A. (2004). Econometric computing with HC and HAC covariance matrix estimators. Journal of Statistical Software 11, issue 10.

Zeileis, A. (2006). Object-oriented computation of sandwich estimators. Journal of Statistical Software 16, issue 9.

See Also

bread, estfun, gcmr, sandwich.

Examples

Run this code
data(epilepsy)
fit <- gcmr(counts ~ offset(log(time)) + visit + trt + visit:trt, data = epilepsy, 
subset = (id != 49), marginal = negbin.marg, cormat = cluster.cormat(id, "ar1"), 
options=gcmr.options(seed=123, nrep=c(25,100) ))
summary(fit)

Run the code above in your browser using DataLab