At the moment, the following are implemented:binomial.marg binomial margins.
Gamma.marg Gamma margins.
gaussian.marg Gaussian margins.
negbin.marg negative binomial margins.
poisson.marg Poisson margins.
weibull.marg Weibull margins.
}
binomial.marg(link = "logit")
Gamma.marg(link = "inverse")
gaussian.marg(link = "identity")
negbin.marg(link = "log")
poisson.marg(link = "log")
weibull.marg(link = "log")family for the special case of generalized linear models.marginal.gcmr representing the marginal component.binomial.marg the response is specified as a factor when the first level denotes failure and all others success or as a two-column matrix with the columns giving the numbers of successes and failures.Negative binomial margins implemented in negbin.marg are parameterized such that $var(Y)=E(Y)+k E(Y)^2$.
For back-compatibility with previous versions of this package, short names for the margins bn.marg, gs.marg, nb.marg, and ps.marg remain valid as an alternative to (preferred) longer versions binomial.marg, gaussian.marg, negbin.marg, and poisson.marg.
gcmr