This package contains Rfunctions related to the papers Masarotto and Varin (2012) and Guolo and Varin (2014). The main function is gcmr, which fits Gaussian copula marginal regression models. Inference is performed through a likelihood approach. Computation of the exact likelihood is possible only for continuous responses, otherwise the likelihood function is approximated by importance sampling. See Masarotto and Varin (2012) for details.
Masarotto, G. and Varin, C. (2012). Gaussian copula marginal regression. Electronic Journal of Statistics 6, 1517--1549.
Pitt, M., Chan D. and Kohn, R. (2006). Efficient Bayesian inference for Gaussian copula regression models. Biometrika 93, 537--554.
Song, P. X.-K. (2000). Multivariate dispersion models generated from Gaussian copula. Scandinavian Journal of Statistics 27, 305--320.