Learn R Programming

gcmr (version 0.7.0)

gcmr.options: Setting Options for Fitting Gaussian Copula Marginal Regression Models

Description

Sets options which affect fitting of Gaussian copula marginal regression models.

Usage

gcmr.options(seed = round(runif(1, 1, 1e+05)), nrep = c(100, 1000), 
    no.se = FALSE, method = c("BFGS", "Nelder-Mead", "CG"))

Arguments

seed
seed of the pseudorandom generator used in the importance sampling algorithm for likelihood approximation in case of discrete responses.
nrep
Monte Carlo size of the importance sampling algorithm for likelihood approximation in case of discrete responses. nrep can be a vector so that the model is fitted with a sequence of different Monte Carlo sizes. In this case, the starting val
no.se
logical. Should standard errors be computed and returned or not?
method
a character string specifying the method argument passed to optim. The default optimization routine is the quasi-Newton algorithm BFGS. See optim for details.

Value

  • A list containing the options.

References

Masarotto, G. and Varin, C. (2012). Gaussian copula marginal regression. Electronic Journal of Statistics 6, 1517--1549. http://projecteuclid.org/euclid.ejs/1346421603.

See Also

gcmr