gcmr.options(seed = round(runif(1, 1, 1e+05)), nrep = c(100, 1000),
no.se = FALSE, method = c("BFGS", "Nelder-Mead", "CG"))nrep can be a vector so that the model is fitted with a sequence of different Monte Carlo sizes. In this case, the starting valoptim. The default optimization routine is the quasi-Newton algorithm BFGS. See optim for details.gcmr