Learn R Programming

gcmr (version 0.2)

gcmr.options: Setting Options for Fitting Gaussian Copula Marginal Regression Models

Description

Sets options which affect fitting of Gaussian copula marginal regression models.

Usage

gcmr.options(seed = round(runif(1, 1, 1e+05)), nrep = c(100, 1000), 
             no.se = FALSE, opt = gcmr.opt)

Arguments

seed
seed of the pseudorandom generator used in the importance sampling algorithm for likelihood approximation in case of noncontinuous responses.
nrep
Monte Carlo size of the importance sampling algorithm for likelihood approximation in case of noncontinuous responses. This could be a vector, in this case different Monte Carlo sizes are used in sequence with starting values for optimization of the like
no.se
logical. Should standard errors be computed and returned or not?
opt
the function used to optimize the likelihood. The default uses nlminb. See gcmr:::gcmr.opt.

Value

  • A list containing the options.

References

Masarotto, G. and Varin. C. (2011). Gaussian copula marginal regression. Preprint.

See Also

gcmr