seed of the pseudorandom generator used in the importance sampling algorithm for likelihood approximation in case of noncontinuous responses.
nrep
Monte Carlo size of the importance sampling algorithm for likelihood approximation in case of noncontinuous responses. This could be a vector, in this case different Monte Carlo sizes are used in sequence with starting values for optimization of the like
no.se
logical. Should standard errors be computed and returned or not?
opt
the function used to optimize the likelihood. The default uses
nlminb. See gcmr:::gcmr.opt.
Value
A list containing the options.
References
Masarotto, G. and Varin. C. (2011). Gaussian copula marginal regression. Preprint.