At the moment, the following are implemented:gs.marg normal margins.
bn.marg binomial margins.
ps.marg Poisson margins.
nb.marg negative binomial margins.
}
gs.marg(link = "identity")
bn.marg(link = "logit")
ps.marg(link = "log")
nb.marg(link = "log")family for the special case of generalized linear models.marginal.gcmr representing the marginal component.bn.marg the response is specified as a factor when the first level denotes failure and all others success or as a two-column matrix with the columns giving the numbers of successes and failures.Negative binomial margins implemented in nb.marg are parameterized such that $var(Y)=E(Y)+k E(Y)^2$.
gcmr