Learn R Programming

gcmr (version 0.7.0)

matern.cormat: Matern Spatial Correlation

Description

Sets a Matern spatial correlation matrix in Gaussian copula marginal regression models.

Usage

matern.cormat(D, alpha = 0.5)

Arguments

D
matrix with values of the distances between pairs of data locations.
alpha
value of the smoothing parameter of the Matern correlation class.

Value

  • An object of class cormat.gcmr representing a Matern correlation matrix.

Details

The Matern correlation function is inherited from the geoR package (Diggle and Ribeiro, 2007).

References

Diggle, P. and Ribeiro, P.J. (2007). Model-based Geostatistics. Springer.

Masarotto, G. and Varin, C. (2012). Gaussian copula marginal regression. Electronic Journal of Statistics 6, 1517--1549. http://projecteuclid.org/euclid.ejs/1346421603.

See Also

gcmr, matern.