Learn R Programming

gcmr (version 0.2)

matern.cormat: Gaussian Copula Regression with Matern Spatial Correlation Matrix

Description

Sets a Matern spatial correlation matrix in Gaussian copula marginal regression models.

Usage

matern.cormat(D, alpha=0.5)

Arguments

D
matrix with values of the distances between pairs of data locations.
alpha
value of the smoothness parameter of the Matern correlation class.

Value

  • An object of class cormat.gcmr representing a Matern correlation matrix.

Details

The Matern correlation function is inherited from the geoR package (Diggle and Ribeiro, 2007).

References

Diggle, P. and Ribeiro, P.J. (2007). Model-based Geostatistics. Springer.

Masarotto, G. and Varin, C. (2011). Gaussian copula marginal regression. Preprint.

See Also

gcmr, matern