Learn R Programming

gcmr (version 0.7.0)

profile.gcmr: Profile Log-Likelihood for Gaussian Copula Marginal Regression Models

Description

Computes the profile log-likelihood for mean response parameters of a Gaussian copula marginal regression model.

Usage

## S3 method for class 'gcmr':
profile(fitted, which, low, up, npoints = 10, 
        display = TRUE, alpha = 0.05, progress.bar = TRUE, ...)

Arguments

fitted
a fitted Gaussian copula marginal regression model of class gcmr.
which
the index of the mean response parameter which should be profiled.
low
the lower limit used in computation of the profile log-likelihood. If this is missing, then the lower limit is set equal to the estimate minus three times its standard error.
up
the upper limit used in computation of the profile log-likelihood. If this is missing, then the upper limit is set equal to the estimate plus three times its standard error.
npoints
number of points used in computation of the profile log-likelihood. Default is 10.
display
should the profile log-likelihood be displayed or not? default is TRUE.
alpha
the significance level, default is 0.05.
progress.bar
logical. If TRUE, a text progress bar is displayed.
...
further arguments.

Value

  • A list with the following components:
  • pointspoints at which the profile log-likelihood is evaluated.
  • profilevalues of the profile log-likelihood.

Details

If display requested, then the profile log-likelihood is smoothed by cubic spline interpolation.

References

Masarotto, G. and Varin, C. (2012). Gaussian copula marginal regression. Electronic Journal of Statistics 6, 1517--1549. http://projecteuclid.org/euclid.ejs/1346421603.

See Also

gcmr

Examples

Run this code
## spatial binomial data
data( malaria )
D <- sp::spDists(cbind(malaria$x, malaria$y))/1000
m <- gcmr(cbind(cases, size-cases) ~ netuse+I(green/100)+phc, data=malaria,
marginal=binomial.marg, cormat=matern.cormat(D), options=gcmr.options(seed=987))
prof <- profile(m, which = 2)
prof

Run the code above in your browser using DataLab