Learn R Programming

gcmr (version 0.2)

profile.gcmr: Profile likelihood for Gaussian Copula Marginal Regression Models

Description

Computes the profile likelihood for a fitted Gaussian copula marginal regression model.

Usage

## S3 method for class 'gcmr':
profile(fitted, which, low = NULL, up = NULL, npoints = 10, 
        display = TRUE, alpha = 0.05, ...)

Arguments

fitted
a fitted Gaussian copula marginal regression model of class gcmr.
which
the index of the parameter which should be profiled.
low
the lower limit used in computation of the profile likelihood. If this is NULL, then the lower limit is set equal to the estimate minus three times its standard error.
up
the upper limit used in computation of the profile likelihood. If this is NULL, then the lower limit is set equal to the estimate plus three times its standard error.
npoints
number of points used in computation of the profile likelihood. Default is 10.
display
should the profile likelihood be displayed or not? default is TRUE.
alpha
the significance level, default is 0.05.
...
further argument.

Value

  • A list with the following components:
  • pointspoints at which the profile likelihood is evaluated.
  • profilevalues of the profile likelihood.

Details

If display requested, then the profile likelihood is smoothed by cubic spline interpolation.

See Also

gcmr

Examples

Run this code
## marginal negative binomial model with Matern correlation
data(scotland)
D.scotland <- spDists(cbind(scotland$longitude, scotland$latitude), longlat=TRUE)
m <- gcmr(observed~offset(log(expected))+AFF+I(latitude/100), data=scotland, 
          marginal=nb.marg(), cormat=matern.cormat(D.scotland), 
          options=list(seed=71271, nrep=100))
prof <- profile(m, which=2, low=0, up=8)
prof

Run the code above in your browser using DataLab