Learn R Programming

gcmr (version 0.7.0)

summary.gcmr: Summarizing Gaussian Copula Marginal Regression Models

Description

These functions are all methods for class gcmr or summary.gcmr objects.

Usage

## S3 method for class 'gcmr':
summary(object, type = "hessian", \dots)
## S3 method for class 'summary.gcmr':
print(x, digits = max(3, getOption("digits") - 3), ...)

Arguments

object
a fitted marginal regression model of class gcmr.
x
an object of class "summary.glm", usually, a result of a call to summary.glm.
type
the method used to compute standard errors, see vcov.gcmr.
digits
the number of significant digits to use when printing.
...
further arguments passed to or from other methods.

Value

  • The function summary.gcmr returns an object of class "summary.glm", a list with some components of the gcmr object, plus
  • se.typethe method used to compute standard errors, see vcov.gcmr.
  • coefficientsa list with components marginal and copula containing the maximum likelihood estimates of the marginal and Gaussian copula parameters, respectively.
  • aicAkaike Information Criterion.

See Also

gcmr

Examples

Run this code
data(epilepsy)
fit <- gcmr(counts ~ offset(log(time)) + visit + trt + visit:trt, data = epilepsy, 
subset = (id != 49), marginal = negbin.marg, cormat = cluster.cormat(id, "ar1"), 
options=gcmr.options(seed=123, nrep=c(25,100) ))
summary(fit)

Run the code above in your browser using DataLab