Learn R Programming

gcmr (version 0.2)

vcov.gcmr: Variance-Covariance Matrix for Parameters in Gaussian Copula Marginal Regression Models

Description

This method extracts or computes the variance-covariance matrix for parameters in a fitted marginal regression model.

Usage

## S3 method for class 'gcmr':
vcov(object, type = c("hessian", "sandwich", "vscore", "cluster", "hac"), ...)

Arguments

object
a fitted marginal regression model of class gcmr.
type
type of variance-covariance matrix. This can be one of the following: ll{ hessian inverse of the observed Fisher information (default). sandwich sandwich variance matrix. vscore cross-product o
...
further arguments passed to function vcovHAC.

Value

  • A matrix containing the estimated covariances between the parameter estimates of a fitted gcmr model.

Details

sandwich and vscore are based on the predictive decomposition of the joint density. cluster uses the decomposition of the data in independent subject-specific blocks. hac is appropriate for time series and uses the implementation in package sandwich (Zeileis, 2006).

References

Andrews, D.W.K. (1991). Heteroskedasticity and autocorrelation consistent covariance matrix estimation. Econometrica, 59, 817--858.

Masarotto, G. and Varin. C. (2011). Gaussian copula marginal regression. Preprint.

Zeleis, A. (2006). Object-oriented computation of sandwich estimators. Journal of Statistical Software 16, issue 9.

See Also

gcmr, sandwich, vcovHAC

Examples

Run this code
data(polio)
## working independence       
m <- gcmr(y~., data=polio, marginal=nb.marg(), cormat=ind.cormat())
m
## HAC variance-covariance matrix
round(vcov(m, "hac"), 2)

Run the code above in your browser using DataLab