type of variance-covariance matrix. This can be one of the following:
ll{
hessian inverse of the observed Fisher information (default).
sandwich sandwich variance matrix.
vscore cross-product o
A matrix containing the estimated covariances between the parameter estimates of a fitted gcmr model.
Details
sandwich and vscore are based on the predictive decomposition of the joint density. cluster uses the decomposition of the data in independent subject-specific blocks. hac is appropriate for time series and uses the implementation in package sandwich (Zeileis, 2006).
data(polio)
## working independence m <- gcmr(y~., data=polio, marginal=nb.marg(), cormat=ind.cormat())
m
## HAC variance-covariance matrixround(vcov(m, "hac"), 2)